"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addListener = addListener;
exports.removeListener = removeListener;
exports.setupNativeEvents = setupNativeEvents;
var _reactNative = require("react-native");
var _EventEmitter = _interopRequireDefault(require("react-native/Libraries/vendor/emitter/EventEmitter"));
var _LKNativeModule = _interopRequireDefault(require("../LKNativeModule"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
// @ts-ignore

// This emitter is going to be used to listen to all the native events (once) and then
// re-emit them on a JS-only emitter.
const nativeEmitter = new _reactNative.NativeEventEmitter(_LKNativeModule.default);
const NATIVE_EVENTS = ['LK_VOLUME_PROCESSED', 'LK_MULTIBAND_PROCESSED'];
const eventEmitter = new _EventEmitter.default();
function setupNativeEvents() {
  for (const eventName of NATIVE_EVENTS) {
    nativeEmitter.addListener(eventName, (...args) => {
      eventEmitter.emit(eventName, ...args);
    });
  }
}
const _subscriptions = new Map();
function addListener(listener, eventName, eventHandler) {
  var _subscriptions$get;
  if (!NATIVE_EVENTS.includes(eventName)) {
    throw new Error(`Invalid event: ${eventName}`);
  }
  if (!_subscriptions.has(listener)) {
    _subscriptions.set(listener, []);
  }
  (_subscriptions$get = _subscriptions.get(listener)) === null || _subscriptions$get === void 0 || _subscriptions$get.push(eventEmitter.addListener(eventName, eventHandler));
}
function removeListener(listener) {
  var _subscriptions$get2;
  (_subscriptions$get2 = _subscriptions.get(listener)) === null || _subscriptions$get2 === void 0 || _subscriptions$get2.forEach(sub => {
    sub.remove();
  });
  _subscriptions.delete(listener);
}
//# sourceMappingURL=EventEmitter.js.map