import { type TrackReferenceOrPlaceholder } from '@livekit/components-react';
import { type LocalAudioTrack, type RemoteAudioTrack } from 'livekit-client';
/**
 * Interface for configuring options for the useMultibandTrackVolume hook.
 * @alpha
 */
export interface MultiBandTrackVolumeOptions {
    /**
     * the number of bands to split the audio into
     */
    bands?: number;
    /**
     * cut off frequency on the lower end
     */
    minFrequency?: number;
    /**
     * cut off frequency on the higher end
     */
    maxFrequency?: number;
    /**
     * update should run every x ms
     */
    updateInterval?: number;
}
/**
 * A hook for tracking the volume of an audio track across multiple frequency bands.
 *
 * @param trackOrTrackReference
 * @returns A number array containing the volume for each frequency band.
 */
export declare function useMultibandTrackVolume(trackOrTrackReference?: LocalAudioTrack | RemoteAudioTrack | TrackReferenceOrPlaceholder, options?: MultiBandTrackVolumeOptions): number[];
